#
# spec file for package gnome-usage
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-usage
Version:        46.0
Release:        1.5
Summary:        System resources viewer for GNOME
License:        GPL-3.0-only
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Apps/Usage
Source:         %{name}-%{version}.tar.zst

BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0) >= 2.74
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.38
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk4) >= 4.12
BuildRequires:  pkgconfig(libadwaita-1) >= 1.5
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(tracker-sparql-3.0)

%description
GNOME Usage is a program to view information about the use of system
resources, like memory and disk space.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%files
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/%{name}
%{_datadir}/applications/org.gnome.Usage.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Usage.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Usage.svg
%{_datadir}/metainfo/org.gnome.Usage.appdata.xml

%files lang -f %{name}.lang

%changelog
* Wed Mar 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Usage now
  - uses ListViews in its performance tabs,
  - split the two performance views
  - and renovated the storage view's look,
  - displays indicators for applications running in background,
  - has an application dialogue instead of directly asking users
    to terminate a process,
  - classifies Android applications inside Waydroid and has an
    indicator for that
  - uses Adwaita's new adaptive dialogues instead of modal
    windows.
  + Updated translations.
- Changes from version 45.1:
  + builds with GCC 14 and Clang 16, together with Vala 0.56.15,
  + avoids glitches in graphs on systems with no swap, due to a
    previous division by zero,
  + has better keyboard navigation with a different selection mode
    for boxes in the storage view, and
  + correctly classifies applications with a long path in its
    cmdline.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to source service for easier updating.
* Sun Sep 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Remove GNOME from the app's name.
  + Porting to GTK4 and the new Adwaita widgets with a completely
    rewritten graph view.
  + Normalising the load, so that 100 %% now means all threads are
    in use.
  + Reducing the re-rendering by making the graphs not scroll
    continuously – at least by default.
  + Making sure Usage doesn't think we had no swap just because 0%%
    is left.
  + Various bug and enhancement fixes.
  + Updated translations.
- Dropped pkgconfig(gtk+-3.0), pkgconfig(libdazzle-1.0) and
  pkgconfig(libhandy-1), added pkgconfig(gee-0.8), pkgconfig(gtk4),
  pkgconfig(libadwaita-1) and pkgconfig(gio-unix-2.0) following
  upstreams port to gtk4 and libadwaita.
* Wed Sep  1 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.38.1:
  + Flag GtkBuilder children as unowned.
  + Prevent reading beyond GTop's args.
  + Prevent navigation to the storage separator.
  + Prevent a double border in the performance sidebar.
  + List compatible form-factors.
- Changes from version 3.38.0:
  + Port to Tracker 3.
  + Updated translations.
- Replace pkgconfig(tracker-sparql-2.0) BuildRequires with
  pkgconfig(tracker-sparql-3.0): follow  upstreams port to
  Tracker 3.
* Sat Sep  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version v3.37.1:
  + Add icons to the pages.
  + app-item: Add application ID based on .desktop file name.
  + app-item: Add application lookup based on cgroup information.
  + app-item: Add newline at end of file.
  + application: Don't access the header bar directly.
  + application: Load icon resources.
  + cpu-sub-view: Don't hardcode the width.
  + cpu-sub-view: Don't horizontally center.
  + header-bar: Make it a HdyHeaderBar.
  + header-bar: Replace the GtkStackSwitcher by a
    HdyViewSwitcherTitle.
  + header-bar: Wrap the search button in a revealer.
  + icons: Add the speedometer-symbolic icon.
  + memory-sub-view: Don't horizontally center.
  + performance-view: Make the search bar adaptive.
  + performance-view: Replace the GtkPaned by a HdyLeaflet.
  + performance-view: Set a minimum width to the content box.
  + performance-view: Use a HdyColumn.
  + process-row: Don't hardcode the width.
  + process: Add function to read cgroup information.
  + storage-view: Replace the GtkPaned by a HdyLeaflet.
  + window: Add a HdyViewSwitcherBar.
  + window: Add action_on_search().
  + window: Drop get_header_bar().
  + window: Inline the header into the window.
  + window: Reduce the hardcoded minimum size.
  + window: Specialize Hdy.ApplicationWindow.
  + window: Use a GtkBuilder template.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Sep  6 2019 luke@ljones.dev
- Update to version None:
  + Add support for GameMode.
  + Support for correctly identfying Flatpaks (specifically Steam).
  + Add an EditorConfig file.
  + Introduce the new Storage panel.
  + Added/updated/fixed translations.
* Fri Mar 22 2019 bjorn.lie@gmail.com
- Update to version 3.32.0:
  + Retire application menu.
  + Simplify the build scripts.
  + Drop RG and EGG libraries.
  + Use libdazzle.
  + Add filter processes option.
  + Support grouping system processes.
  + Add new application icon.
  + Updated translations.
- Add pkgconfig(libdazzle-1.0) BuildRequires: New dependency.
* Tue Sep 25 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Support Adwaita dark better.
  + Fix error message grammar/typos.
  + Fix compatibility with newer Vala.
  + Use proper POSIX API in quit-process-dialog.
  + Add scrolling animation to performance view.
  + Update screenshots.
  + Updated translations.
* Mon Mar 12 2018 bjorn.lie@gmail.com
- Update to version 3.28.0:
  + Drop "accountsservice" dependency.
  + process-row: Consume AccountsService data over DBus.
  + Updated translations.
- Drop pkgconfig(accountsservice) BuildRequires: No longer needed.
* Sun Mar  4 2018 bjorn.lie@gmail.com
- Update to version 3.27.92:
  + Add categories to desktop file.
  + Fix flatpak manifest file URLs.
  + Updated translations.
- Drop update-desktop-files BuildRequires and no longer use
  suse_update_desktop_file macro, no longer needed.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Feb  9 2018 bjorn.lie@gmail.com
- Update to version 3.27.90:
  + Updated translations.
- Following upstreams License changes, replace AGPL-3.0 with new
  upstream GPL-3.0 in spec.
* Mon Feb  5 2018 jengelh@inai.de
- Update description.
* Wed Jan 24 2018 bjorn.lie@gmail.com
- Update to version 0.4.5~20180114.6452220:
  + license: Add correct license file with GPLv3.
  + Updated translations.
- Switch Licence tag ref upstreams correction.
* Thu Jan  4 2018 zaitor@opensuse.org
- Update to version 0.4.5~20180103.65d5f93:
  + swap-speedometer: Initialize label to "0%%".
  + Updated translations.
* Fri Dec 22 2017 zaitor@opensuse.org
- Initial packaging for openSUSE.
